==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AccessPolicyRuleApplicationSignOn.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AccessPolicyRuleApplicationSignOnAccess;
import com.okta.sdk.resource.model.VerificationMethod;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyRuleApplicationSignOn
 */
@JsonPropertyOrder({ AccessPolicyRuleApplicationSignOn.JSON_PROPERTY_ACCESS,
        AccessPolicyRuleApplicationSignOn.JSON_PROPERTY_VERIFICATION_METHOD })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AccessPolicyRuleApplicationSignOn implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACCESS = "access";
    private AccessPolicyRuleApplicationSignOnAccess access;

    public static final String JSON_PROPERTY_VERIFICATION_METHOD = "verificationMethod";
    private VerificationMethod verificationMethod;

    public AccessPolicyRuleApplicationSignOn() {
    }

    public AccessPolicyRuleApplicationSignOn access(AccessPolicyRuleApplicationSignOnAccess access) {

        this.access = access;
        return this;
    }

    /**
     * Get access
     *
     * @return access
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACCESS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AccessPolicyRuleApplicationSignOnAccess getAccess() {
        return access;
    }

    @JsonProperty(JSON_PROPERTY_ACCESS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAccess(AccessPolicyRuleApplicationSignOnAccess access) {
        this.access = access;
    }

    public AccessPolicyRuleApplicationSignOn verificationMethod(VerificationMethod verificationMethod) {

        this.verificationMethod = verificationMethod;
        return this;
    }

    /**
     * Get verificationMethod
     *
     * @return verificationMethod
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFICATION_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public VerificationMethod getVerificationMethod() {
        return verificationMethod;
    }

    @JsonProperty(JSON_PROPERTY_VERIFICATION_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerificationMethod(VerificationMethod verificationMethod) {
        this.verificationMethod = verificationMethod;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyRuleApplicationSignOn accessPolicyRuleApplicationSignOn = (AccessPolicyRuleApplicationSignOn) o;
        return Objects.equals(this.access, accessPolicyRuleApplicationSignOn.access)
                && Objects.equals(this.verificationMethod, accessPolicyRuleApplicationSignOn.verificationMethod);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(access, verificationMethod);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyRuleApplicationSignOn {\n");
        sb.append("    access: ").append(toIndentedString(access)).append("\n");
        sb.append("    verificationMethod: ").append(toIndentedString(verificationMethod)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/AccessPolicyRuleApplicationSignOn.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AccessPolicyRuleApplicationSignOnAccess;
import com.okta.sdk.resource.model.VerificationMethod;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyRuleApplicationSignOn
 */
@JsonPropertyOrder({ AccessPolicyRuleApplicationSignOn.JSON_PROPERTY_ACCESS,
        AccessPolicyRuleApplicationSignOn.JSON_PROPERTY_VERIFICATION_METHOD })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AccessPolicyRuleApplicationSignOn implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACCESS = "access";
    private AccessPolicyRuleApplicationSignOnAccess access;

    public static final String JSON_PROPERTY_VERIFICATION_METHOD = "verificationMethod";
    private VerificationMethod verificationMethod;

    public AccessPolicyRuleApplicationSignOn() {
    }

    public AccessPolicyRuleApplicationSignOn access(AccessPolicyRuleApplicationSignOnAccess access) {

        this.access = access;
        return this;
    }

    /**
     * Get access
     *
     * @return access
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACCESS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AccessPolicyRuleApplicationSignOnAccess getAccess() {
        return access;
    }

    @JsonProperty(JSON_PROPERTY_ACCESS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAccess(AccessPolicyRuleApplicationSignOnAccess access) {
        this.access = access;
    }

    public AccessPolicyRuleApplicationSignOn verificationMethod(VerificationMethod verificationMethod) {

        this.verificationMethod = verificationMethod;
        return this;
    }

    /**
     * Get verificationMethod
     *
     * @return verificationMethod
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFICATION_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public VerificationMethod getVerificationMethod() {
        return verificationMethod;
    }

    @JsonProperty(JSON_PROPERTY_VERIFICATION_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerificationMethod(VerificationMethod verificationMethod) {
        this.verificationMethod = verificationMethod;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyRuleApplicationSignOn accessPolicyRuleApplicationSignOn = (AccessPolicyRuleApplicationSignOn) o;
        return Objects.equals(this.access, accessPolicyRuleApplicationSignOn.access)
                && Objects.equals(this.verificationMethod, accessPolicyRuleApplicationSignOn.verificationMethod);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(access, verificationMethod);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyRuleApplicationSignOn {\n");
        sb.append("    access: ").append(toIndentedString(access)).append("\n");
        sb.append("    verificationMethod: ").append(toIndentedString(verificationMethod)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
